Module executor

Module executor 

Workflow executor implementation Workflow executor for tool composition DSL

This module provides the execution engine for running tool composition workflows defined using the ToolExpr DSL.

Structs

CompositionExecutor
Executor for running tool composition workflows