pub struct StreamToolCall {
pub index: u32,
pub id: Option<String>,
pub tool_type: Option<String>,
pub function: Option<StreamFunctionCall>,
}Expand description
Streaming tool call fragment.
During streaming, tool calls are sent incrementally across multiple chunks.
The index field identifies which tool call each fragment belongs to.
Fields
index- Tool call index for reassemblyid- Tool call ID (first chunk only)tool_type- Tool type (first chunk only)function- Function call fragment
Fields
index: u32Index to identify which tool call this fragment belongs to
id: Option<String>Tool call ID (only present in the first chunk)
tool_type: Option<String>Tool type (only present in the first chunk)
function: Option<StreamFunctionCall>Function call data (may be partial)