ServerCapabilities

Struct ServerCapabilities 

pub struct ServerCapabilities {
    pub experimental: Option<Value>,
    pub logging: Option<Value>,
    pub prompts: Option<PromptsCapability>,
    pub resources: Option<ResourcesCapability>,
    pub tools: Option<ToolsCapability>,
}
Server capabilities declaration.

Informs the client about which features the server provides. The client can then use this information to discover and use available tools, resources, and prompts.

Fields

  • experimental - Experimental capabilities (future use)
  • logging - Support for log message notifications
  • prompts - Support for prompt templates
  • resources - Support for resource access
  • tools - Support for tool invocation

Fields

experimental: Option<Value>

Experimental capabilities (reserved for future use)

logging: Option<Value>

Support for logging notifications

prompts: Option<PromptsCapability>

Support for prompt templates

resources: Option<ResourcesCapability>

Support for resource access

tools: Option<ToolsCapability>

Support for tool invocation