pub struct SessionMessageId(/* private fields */);Expand description
Globally unique idempotency key supplied by the sender.
Implementations
Sourceimpl SessionMessageId
impl SessionMessageId
pub fn new() -> SessionMessageId
pub fn parse( value: impl Into<String>, ) -> Result<SessionMessageId, SessionMessageValidationError>
pub fn as_str(&self) -> &str
Sourcepub fn stable(namespace: &str, value: &Value) -> SessionMessageId
pub fn stable(namespace: &str, value: &Value) -> SessionMessageId
Stable id for runtime events whose producer already has a durable semantic identity but not a UUID-form message id.