Module codex_app_server_executor

Module codex_app_server_executor 

Long-lived codex app-server executor with interactive approval relay. Long-lived Codex app-server executor with Bamboo approval relay.

The app-server process is retained by a warm actor worker, while logical Codex threads are keyed by Bamboo session id. Server-to-client approval requests are relayed through HostBridge and fail closed after 300 seconds.

Structs

CodexAppServerExecutor
codex app-server implementation of the Codex executor mode.