pub struct BuiltinToolExecutor { /* private fields */ }Expand description
Built-in tool executor that uses ToolRegistry for dynamic dispatch
Implementations
Sourceimpl BuiltinToolExecutor
impl BuiltinToolExecutor
Sourcepub fn new_with_permissions(
permission_checker: Arc<dyn PermissionChecker>,
) -> Self
pub fn new_with_permissions( permission_checker: Arc<dyn PermissionChecker>, ) -> Self
Creates a new executor with a permission checker
Sourcepub fn new_with_config(config: Arc<RwLock<Config>>) -> Self
pub fn new_with_config(config: Arc<RwLock<Config>>) -> Self
Creates a new executor that can read the shared, hot-reloadable config.
Use this when running inside the Bamboo server so tools (notably
http_request) honor proxy settings from config.json.
Sourcepub fn new_with_config_and_permissions(
config: Arc<RwLock<Config>>,
permission_checker: Arc<dyn PermissionChecker>,
) -> Self
pub fn new_with_config_and_permissions( config: Arc<RwLock<Config>>, permission_checker: Arc<dyn PermissionChecker>, ) -> Self
Creates a new executor with both shared config and a permission checker.
Sourcepub fn with_registry(registry: ToolRegistry) -> Self
pub fn with_registry(registry: ToolRegistry) -> Self
Creates a new executor from an existing registry
Sourcepub fn registry(&self) -> &ToolRegistry
pub fn registry(&self) -> &ToolRegistry
Returns a reference to the internal registry
Sourcepub fn tool_schemas() -> Vec<ToolSchema>
pub fn tool_schemas() -> Vec<ToolSchema>
Returns all built-in tool schemas
Sourcepub fn register_tool<T: Tool + 'static>(&self, tool: T) -> Result<(), ToolError>
pub fn register_tool<T: Tool + 'static>(&self, tool: T) -> Result<(), ToolError>
Registers a custom tool to this executor
Sourcepub fn register_tool_with_guide<T, G>(
&self,
tool: T,
guide: G,
) -> Result<(), ToolError>
pub fn register_tool_with_guide<T, G>( &self, tool: T, guide: G, ) -> Result<(), ToolError>
Register a tool with its guide
Sourcepub fn build_enhanced_prompt(&self, context: GuideBuildContext) -> String
pub fn build_enhanced_prompt(&self, context: GuideBuildContext) -> String
Build enhanced prompt for all registered tools